@@ -211,7 +211,7 @@ The port number (INET) or name (UNIX) of the lock server.  Defaults to
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 1999-2013 by Wilson Snyder.  This package is free software; you
+Copyright 1999-2017 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
@@ -249,7 +249,7 @@ use Carp;
 # Other configurable settings.
 $Debug = 0;
 
-$VERSION = '1.492';
+$VERSION = '1.494';
 
 ######################################################################
 #### Useful Globals
@@ -510,7 +510,7 @@ sub _request_attempt {
 
     my $fh;
     if ($self->{family} eq 'INET') {
-	_timelog("Locker->Trying host $host\n") if $Debug;
+	_timelog("Locker->Trying host $host $self->{port}\n") if $Debug;
 	$fh = IO::Socket::INET->new( Proto     => _tcp_proto(),
 				     PeerAddr  => $host,
 				     PeerPort  => $self->{port}, );
