@@ -49,7 +49,7 @@ The port number (INET) or name (UNIX) of the lock server.  Defaults to
 
 The latest version is available from CPAN and from L<http://www.veripool.org/>.
 
-Copyright 1999-2013 by Wilson Snyder.  This package is free software; you
+Copyright 1999-2017 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
@@ -87,7 +87,7 @@ use Carp;
 # Other configurable settings.
 $Debug = 0;
 
-$VERSION = '1.492';
+$VERSION = '1.494';
 $Hostname = IPC::Locker::hostfqdn();
 
 ######################################################################
@@ -160,8 +160,9 @@ sub start_server {
     $SIG{INT}= \&sig_INT;
     $SIG{HUP}= \&sig_INT;
 
+    $! = 0;
     while (!$Interrupts) {
-	_timelog("Pre-Poll $!\n") if $Debug;
+	_timelog("Pre-poll $!\n") if $Debug;
 	#use Data::Dumper; Carp::cluck(Dumper(\%Clients, \%Locks));
 	$! = 0;
 	my (@r, @w, @e);
